@@ -4,9 +4,9 @@ use hudsucker::{
     hyper::{Body, Request, Response},
     *,
 };
-use log::*;
 use rustls_pemfile as pemfile;
 use std::net::SocketAddr;
+use tracing::*;
 
 async fn shutdown_signal() {
     tokio::signal::ctrl_c()
@@ -36,7 +36,7 @@ impl HttpHandler for LogHandler {
 
 #[tokio::main]
 async fn main() {
-    env_logger::init();
+    tracing_subscriber::fmt::init();
 
     let mut private_key_bytes: &[u8] = include_bytes!("ca/hudsucker.key");
     let mut ca_cert_bytes: &[u8] = include_bytes!("ca/hudsucker.pem");
